pub trait Analysis<'a, I: Instantiable>where
Self: Sized + 'a,{
// Required method
fn build(netlist: &'a Netlist<I>) -> Result<Self, Error>;
}Expand description
A common trait of analyses than can be performed on a netlist. An analysis becomes stale when the netlist is modified.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".